@@ -31,7 +31,7 @@ autoreconf --force --install --symlink || exit $?
 
 cd $olddir
 
-conf_flags="--enable-maintainer-mode"
+conf_flags="--enable-shave"
 
 if test x$NOCONFIGURE = x; then
   echo Running $srcdir/configure $conf_flags "$@" ...
