@@ -165,7 +165,8 @@ static const struct {
   { "gtk-handle",	"GtkVScale",			"slider",	-1,		NULL,		NULL },
   { "gtk-trough",	"GtkVScrollbar",		"box",		-1,		_trough_detail,	NULL },
   { NULL,		"GtkVScrollbar",		"box",		-1,		NULL,		get_stepper },
-  { "gtk-handle",	"GtkVScrollbar",		"slider",	-1,		NULL,		NULL }
+  { "gtk-handle",	"GtkVScrollbar",		"slider",	-1,		NULL,		NULL },
+  { "gtk-focus",	NULL,				"focus",	-1,		NULL,		NULL }
 };
 
 char const *
@@ -190,9 +191,10 @@ gce_maps_match_role (GtkWidget		*widget,
 
 	had_match = FALSE;
 	for (unsigned int i = 0; i < G_N_ELEMENTS (_widgets); i++) {
-		if (0 == g_strcmp0 (type_name, _widgets[i].type_name)) {
-			had_match = TRUE;
+		if (NULL == _widgets[i].type_name ||
+		    0 == g_strcmp0 (type_name, _widgets[i].type_name)) {
 			if (0 == g_strcmp0 (primitive, _widgets[i].primitive)) {
+				had_match = TRUE;
 				if (_widgets[i].shadow > -1) {
 					/* Match by shadow. */
 					if (_widgets[i].shadow == shadow)
