@@ -68,11 +68,9 @@ rectangle (GceStyle		*self,
 			height = height == -1 ? h : height;
 		}
 
-		if (fill) {
-			ccss_cairo_style_draw_rectangle (style, cr, x, y, width, height);
-		} else {
-			ccss_cairo_style_draw_outline (style, cr, x, y, width, height);
-		}
+		/* FIXME: force 'background: none' by inserting/frobbing? */
+		ccss_cairo_style_draw_rectangle (style, cr, x, y, width, height);
+
 
 		cairo_destroy (cr), cr = NULL;
 		ccss_style_destroy (style), style = NULL;
@@ -130,44 +128,6 @@ gap (GceStyle		*self,
 	}
 }
 
-static void
-line (GceStyle		*self,
-      GceNode		*node,
-      GdkWindow		*window, 
-      GdkRectangle	*area, 
-      GtkWidget		*widget, 
-      gint		 x1, 
-      gint		 x2, 
-      gint		 y1, 
-      gint		 y2)
-{
-	cairo_t		*cr;
-	ccss_style_t	*style = NULL;
-
-	g_return_if_fail (self);
-	g_return_if_fail (self->stylesheet);
-
-	if (node) {
-		style = ccss_stylesheet_query (self->stylesheet, (ccss_node_t *) node);
-	} else if (self->selector) {
-		style = ccss_stylesheet_query_type (self->stylesheet, self->selector);
-	}
-
-	if (style) {
-		cr = gdk_cairo_create (window);
-
-		if (area) {
-			gdk_cairo_rectangle (cr, area);
-			cairo_clip (cr);
-		}
-
-		ccss_cairo_style_draw_line (style, cr, x1, x2, y1, y2);
-
-		cairo_destroy (cr), cr = NULL;
-		ccss_style_destroy (style), style = NULL;
-	}
-}
-
 static void 
 draw_hline (GtkStyle		*self, 
 	    GdkWindow		*window, 
@@ -181,9 +141,12 @@ draw_hline (GtkStyle		*self,
 {
 	char const	*role;
 	GceNode		*node = NULL;
+	gint		 width = x2 - x1 + 1;
+	gint		 height = 2;
 
 	detail = gce_maps_get_detail (detail);
-	role = gce_maps_match_role (widget, "hline", -1, detail, x1, y, x2 - x1, -1);
+	role = gce_maps_match_role (widget, "hline", -1, detail,
+				    x1, y, width, height);
 
 	if (widget)
 		node = gce_node_cache_fetch_node (widget, 
@@ -192,7 +155,9 @@ draw_hline (GtkStyle		*self,
 			NULL, NULL, NULL, NULL, NULL,
 			role ? role : "hline");
 
-	line (GCE_STYLE (self), node, window, area, widget, x1, x2, y, y);
+	/* FIXME: hardcode line width of 2, learn about wide separators. */
+	rectangle (GCE_STYLE (self), node, window, area, widget,
+		   x1, y, width, height, TRUE);
 
 	gce_node_cache_release_node (node), node = NULL;
 }
@@ -210,9 +175,12 @@ draw_vline (GtkStyle		*self,
 {
 	char const	*role;
 	GceNode		*node = NULL;
+	gint		 width = 2;
+	gint		 height = y2 - y1 + 1;
 
 	detail = gce_maps_get_detail (detail);
-	role = gce_maps_match_role (widget, "vline", -1, detail, x, y1, -1, y2 - y1);
+	role = gce_maps_match_role (widget, "vline", -1, detail,
+				    x, y1, width, height);
 
 	if (widget)
 		node = gce_node_cache_fetch_node (widget, 
@@ -221,7 +189,9 @@ draw_vline (GtkStyle		*self,
 			NULL, NULL, NULL, NULL, NULL,
 			role ? role : "vline");
 
-	line (GCE_STYLE (self), node, window, area, widget, x, x, y1, y2);
+	/* FIXME: hardcode line width of 2, learn about wide separators. */
+	rectangle (GCE_STYLE (self), node, window, area, widget,
+		   x, y1, width, height, TRUE);
 
 	gce_node_cache_release_node (node), node = NULL;
 
@@ -254,7 +224,7 @@ draw_shadow (GtkStyle		*self,
 			NULL, NULL, NULL, NULL,
 			role ? role : "shadow");
 
-	rectangle (GCE_STYLE (self), node, window, area, widget, 
+	rectangle (GCE_STYLE (self), node, window, area, widget,
 		   x, y, width, height, TRUE);
 
 	gce_node_cache_release_node (node), node = NULL;
